==> OSCA.intro_1.16.0.tar.gz: OSCA.intro/inst/doc/book/analysis-overview.md <==
# Analysis overview

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Outline

This chapter provides an overview of the framework of a typical scRNA-seq analysis workflow (Figure \@ref(fig:scworkflow)).

<div class="figure">
<img src="images/workflow.png" alt="Schematic of a typical scRNA-seq analysis workflow. Each stage (separated by dashed lines) consists of a number of specific steps, many of which operate on and modify a `SingleCellExperiment` instance." width="735" />
<p class="caption">(\#fig:scworkflow)Schematic of a typical scRNA-seq analysis workflow. Each stage (separated by dashed lines) consists of a number of specific steps, many of which operate on and modify a `SingleCellExperiment` instance.</p>
</div>

In the simplest case, the workflow has the following form:

1. We compute quality control metrics to remove low-quality cells that would interfere with downstream analyses.
These cells may have been damaged during processing or may not have been fully captured by the sequencing protocol.
Common metrics includes the total counts per cell, the proportion of spike-in or mitochondrial reads and the number of detected features.
2. We convert the counts into normalized expression values to eliminate cell-specific biases (e.g., in capture efficiency).
This allows us to perform explicit comparisons across cells in downstream steps like clustering.
We also apply a transformation, typically log, to adjust for the mean-variance relationship. 
3. We perform feature selection to pick a subset of interesting features for downstream analysis.
This is done by modelling the variance across cells for each gene and retaining genes that are highly variable.
The aim is to reduce computational overhead and noise from uninteresting genes.
4. We apply dimensionality reduction to compact the data and further reduce noise.
Principal components analysis is typically used to obtain an initial low-rank representation for more computational work,
followed by more aggressive methods like $t$-stochastic neighbor embedding for visualization purposes.
5. We cluster cells into groups according to similarities in their (normalized) expression profiles.
This aims to obtain groupings that serve as empirical proxies for distinct biological states.
We typically interpret these groupings by identifying differentially expressed marker genes between clusters.

Subsequent chapters will describe each analysis step in more detail.

## Quick start (simple)

Here, we use the a droplet-based retina dataset from @macosko2015highly, provided in the *[scRNAseq](https://bioconductor.org/packages/3.21/scRNAseq)* package.
This starts from a count matrix and finishes with clusters (Figure \@ref(fig:quick-start-umap)) in preparation for biological interpretation.
Similar workflows are available in abbreviated form in later parts of the book.


``` r
library(scRNAseq)
sce <- MacoskoRetinaData()

# Quality control (using mitochondrial genes).
library(scater)
is.mito <- grepl("^MT-", rownames(sce))
qcstats <- perCellQCMetrics(sce, subsets=list(Mito=is.mito))
filtered <- quickPerCellQC(qcstats, percent_subsets="subsets_Mito_percent")
sce <- sce[, !filtered$discard]

# Normalization.
sce <- logNormCounts(sce)

# Feature selection.
library(scran)
dec <- modelGeneVar(sce)
hvg <- getTopHVGs(dec, prop=0.1)

# PCA.
library(scater)
set.seed(1234)
sce <- runPCA(sce, ncomponents=25, subset_row=hvg)

# Clustering.
library(bluster)
colLabels(sce) <- clusterCells(sce, use.dimred='PCA',
    BLUSPARAM=NNGraphParam(cluster.fun="louvain"))    

# Visualization.
sce <- runUMAP(sce, dimred = 'PCA')
plotUMAP(sce, colour_by="label")
```

<div class="figure">
<img src="analysis-overview_files/figure-html/quick-start-umap-1.png" alt="UMAP plot of the retina dataset, where each point is a cell and is colored by the assigned cluster identity." width="672" />
<p class="caption">(\#fig:quick-start-umap)UMAP plot of the retina dataset, where each point is a cell and is colored by the assigned cluster identity.</p>
</div>

``` r
# Marker detection.
markers <- findMarkers(sce, test.type="wilcox", direction="up", lfc=1)
```

## Quick start (multiple batches)

Here we use the pancreas Smart-seq2 dataset from @segerstolpe2016singlecell, again provided in the *[scRNAseq](https://bioconductor.org/packages/3.21/scRNAseq)* package.
This starts from a count matrix and finishes with clusters (Figure \@ref(fig:quick-start-umap)) with some additional tweaks to eliminate uninteresting batch effects between individuals.
Note that a more elaborate analysis of the same dataset with justifications for each step is available in [Workflow Chapter 8](http://bioconductor.org/books/3.21/OSCA.workflows/segerstolpe-human-pancreas-smart-seq2.html#segerstolpe-human-pancreas-smart-seq2).


``` r
sce <- SegerstolpePancreasData()

# Quality control (using ERCCs).
qcstats <- perCellQCMetrics(sce)
filtered <- quickPerCellQC(qcstats, percent_subsets="altexps_ERCC_percent")
sce <- sce[, !filtered$discard]

# Normalization.
sce <- logNormCounts(sce)

# Feature selection, blocking on the individual of origin.
dec <- modelGeneVar(sce, block=sce$individual)
hvg <- getTopHVGs(dec, prop=0.1)

# Batch correction.
library(batchelor)
set.seed(1234)
sce <- correctExperiments(sce, batch=sce$individual, 
    subset.row=hvg, correct.all=TRUE)

# Clustering.
colLabels(sce) <- clusterCells(sce, use.dimred='corrected')

# Visualization.
sce <- runUMAP(sce, dimred = 'corrected')
gridExtra::grid.arrange(
    plotUMAP(sce, colour_by="label"),
    plotUMAP(sce, colour_by="individual"),
    ncol=2
)
```

<div class="figure">
<img src="analysis-overview_files/figure-html/quick-start2-umap-1.png" alt="UMAP plot of the pancreas dataset, where each point is a cell and is colored by the assigned cluster identity (left) or the individual of origin (right)." width="960" />
<p class="caption">(\#fig:quick-start2-umap)UMAP plot of the pancreas dataset, where each point is a cell and is colored by the assigned cluster identity (left) or the individual of origin (right).</p>
</div>

``` r
# Marker detection, blocking on the individual of origin.
markers <- findMarkers(sce, test.type="wilcox", direction="up", lfc=1)
```

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.5.0 RC (2025-04-04 r88126)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0  LAPACK version 3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] batchelor_1.24.0            bluster_1.18.0             
 [3] scran_1.36.0                scater_1.36.0              
 [5] ggplot2_3.5.2               scuttle_1.18.0             
 [7] scRNAseq_2.21.1             SingleCellExperiment_1.30.0
 [9] SummarizedExperiment_1.38.0 Biobase_2.68.0             
[11] GenomicRanges_1.60.0        GenomeInfoDb_1.44.0        
[13] IRanges_2.42.0              S4Vectors_0.46.0           
[15] BiocGenerics_0.54.0         generics_0.1.3             
[17] MatrixGenerics_1.20.0       matrixStats_1.5.0          
[19] BiocStyle_2.36.0            rebook_1.18.0              

loaded via a namespace (and not attached):
  [1] jsonlite_2.0.0            CodeDepends_0.6.6        
  [3] magrittr_2.0.3            ggbeeswarm_0.7.2         
  [5] GenomicFeatures_1.60.0    gypsum_1.4.0             
  [7] farver_2.1.2              rmarkdown_2.29           
  [9] BiocIO_1.18.0             vctrs_0.6.5              
 [11] DelayedMatrixStats_1.30.0 memoise_2.0.1            
 [13] Rsamtools_2.24.0          RCurl_1.98-1.17          
 [15] htmltools_0.5.8.1         S4Arrays_1.8.0           
 [17] AnnotationHub_3.16.0      curl_6.2.2               
 [19] BiocNeighbors_2.2.0       Rhdf5lib_1.30.0          
 [21] SparseArray_1.8.0         rhdf5_2.52.0             
 [23] sass_0.4.10               alabaster.base_1.8.0     
 [25] bslib_0.9.0               alabaster.sce_1.8.0      
 [27] httr2_1.1.2               cachem_1.1.0             
 [29] ResidualMatrix_1.18.0     GenomicAlignments_1.44.0 
 [31] igraph_2.1.4              lifecycle_1.0.4          
 [33] pkgconfig_2.0.3           rsvd_1.0.5               
 [35] Matrix_1.7-3              R6_2.6.1                 
 [37] fastmap_1.2.0             GenomeInfoDbData_1.2.14  
 [39] digest_0.6.37             colorspace_2.1-1         
 [41] AnnotationDbi_1.70.0      dqrng_0.4.1              
 [43] irlba_2.3.5.1             ExperimentHub_2.16.0     
 [45] RSQLite_2.3.9             beachmat_2.24.0          
 [47] labeling_0.4.3            filelock_1.0.3           
 [49] httr_1.4.7                abind_1.4-8              
 [51] compiler_4.5.0            bit64_4.6.0-1            
 [53] withr_3.0.2               BiocParallel_1.42.0      
 [55] viridis_0.6.5             DBI_1.2.3                
 [57] HDF5Array_1.36.0          alabaster.ranges_1.8.0   
 [59] alabaster.schemas_1.8.0   rappdirs_0.3.3           
 [61] DelayedArray_0.34.0       rjson_0.2.23             
 [63] tools_4.5.0               vipor_0.4.7              
 [65] beeswarm_0.4.0            glue_1.8.0               
 [67] h5mread_1.0.0             restfulr_0.0.15          
 [69] rhdf5filters_1.20.0       grid_4.5.0               
 [71] cluster_2.1.8.1           gtable_0.3.6             
 [73] ensembldb_2.32.0          metapod_1.16.0           
 [75] BiocSingular_1.24.0       ScaledMatrix_1.16.0      
 [77] XVector_0.48.0            RcppAnnoy_0.0.22         
 [79] ggrepel_0.9.6             BiocVersion_3.21.1       
 [81] pillar_1.10.2             limma_3.64.0             
 [83] dplyr_1.1.4               BiocFileCache_2.16.0     
 [85] lattice_0.22-7            FNN_1.1.4.1              
 [87] rtracklayer_1.68.0        bit_4.6.0                
 [89] tidyselect_1.2.1          locfit_1.5-9.12          
 [91] Biostrings_2.76.0         knitr_1.50               
 [93] gridExtra_2.3             bookdown_0.43            
 [95] ProtGenerics_1.40.0       edgeR_4.6.0              
 [97] xfun_0.52                 statmod_1.5.0            
 [99] UCSC.utils_1.4.0          lazyeval_0.2.2           
[101] yaml_2.3.10               evaluate_1.0.3           
[103] codetools_0.2-20          tibble_3.2.1             
[105] alabaster.matrix_1.8.0    BiocManager_1.30.25      
[107] graph_1.86.0              cli_3.6.4                
[109] uwot_0.2.3                munsell_0.5.1            
[111] jquerylib_0.1.4           Rcpp_1.0.14              
[113] dir.expiry_1.16.0         dbplyr_2.5.0             
[115] png_0.1-8                 XML_3.99-0.18            
[117] parallel_4.5.0            blob_1.2.4               
[119] AnnotationFilter_1.32.0   sparseMatrixStats_1.20.0 
[121] bitops_1.0-9              viridisLite_0.4.2        
[123] alabaster.se_1.8.0        scales_1.3.0             
[125] crayon_1.5.3              rlang_1.1.6              
[127] cowplot_1.1.3             KEGGREST_1.48.0          
```
</div>

==> OSCA.intro_1.16.1.tar.gz: OSCA.intro/inst/doc/book/analysis-overview.md <==
# Analysis overview

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Outline

This chapter provides an overview of the framework of a typical scRNA-seq analysis workflow (Figure \@ref(fig:scworkflow)).

<div class="figure">
<img src="images/workflow.png" alt="Schematic of a typical scRNA-seq analysis workflow. Each stage (separated by dashed lines) consists of a number of specific steps, many of which operate on and modify a `SingleCellExperiment` instance." width="735" />
<p class="caption">(\#fig:scworkflow)Schematic of a typical scRNA-seq analysis workflow. Each stage (separated by dashed lines) consists of a number of specific steps, many of which operate on and modify a `SingleCellExperiment` instance.</p>
</div>

In the simplest case, the workflow has the following form:

1. We compute quality control metrics to remove low-quality cells that would interfere with downstream analyses.
These cells may have been damaged during processing or may not have been fully captured by the sequencing protocol.
Common metrics includes the total counts per cell, the proportion of spike-in or mitochondrial reads and the number of detected features.
2. We convert the counts into normalized expression values to eliminate cell-specific biases (e.g., in capture efficiency).
This allows us to perform explicit comparisons across cells in downstream steps like clustering.
We also apply a transformation, typically log, to adjust for the mean-variance relationship. 
3. We perform feature selection to pick a subset of interesting features for downstream analysis.
This is done by modelling the variance across cells for each gene and retaining genes that are highly variable.
The aim is to reduce computational overhead and noise from uninteresting genes.
4. We apply dimensionality reduction to compact the data and further reduce noise.
Principal components analysis is typically used to obtain an initial low-rank representation for more computational work,
followed by more aggressive methods like $t$-stochastic neighbor embedding for visualization purposes.
5. We cluster cells into groups according to similarities in their (normalized) expression profiles.
This aims to obtain groupings that serve as empirical proxies for distinct biological states.
We typically interpret these groupings by identifying differentially expressed marker genes between clusters.

Subsequent chapters will describe each analysis step in more detail.

## Quick start (simple)

Here, we use the a droplet-based retina dataset from @macosko2015highly, provided in the *[scRNAseq](https://bioconductor.org/packages/3.21/scRNAseq)* package.
This starts from a count matrix and finishes with clusters (Figure \@ref(fig:quick-start-umap)) in preparation for biological interpretation.
Similar workflows are available in abbreviated form in later parts of the book.


``` r
library(scRNAseq)
sce <- MacoskoRetinaData()

# Quality control (using mitochondrial genes).
library(scater)
is.mito <- grepl("^MT-", rownames(sce))
qcstats <- perCellQCMetrics(sce, subsets=list(Mito=is.mito))
filtered <- quickPerCellQC(qcstats, percent_subsets="subsets_Mito_percent")
sce <- sce[, !filtered$discard]

# Normalization.
sce <- logNormCounts(sce)

# Feature selection.
library(scran)
dec <- modelGeneVar(sce)
hvg <- getTopHVGs(dec, prop=0.1)

# PCA.
library(scater)
set.seed(1234)
sce <- runPCA(sce, ncomponents=25, subset_row=hvg)

# Clustering.
library(bluster)
colLabels(sce) <- clusterCells(sce, use.dimred='PCA',
    BLUSPARAM=NNGraphParam(cluster.fun="louvain"))    

# Visualization.
sce <- runUMAP(sce, dimred = 'PCA')
plotUMAP(sce, colour_by="label")
```

<div class="figure">
<img src="analysis-overview_files/figure-html/quick-start-umap-1.png" alt="UMAP plot of the retina dataset, where each point is a cell and is colored by the assigned cluster identity." width="672" />
<p class="caption">(\#fig:quick-start-umap)UMAP plot of the retina dataset, where each point is a cell and is colored by the assigned cluster identity.</p>
</div>

``` r
# Marker detection.
markers <- findMarkers(sce, test.type="wilcox", direction="up", lfc=1)
```

## Quick start (multiple batches)

Here we use the pancreas Smart-seq2 dataset from @segerstolpe2016singlecell, again provided in the *[scRNAseq](https://bioconductor.org/packages/3.21/scRNAseq)* package.
This starts from a count matrix and finishes with clusters (Figure \@ref(fig:quick-start-umap)) with some additional tweaks to eliminate uninteresting batch effects between individuals.
Note that a more elaborate analysis of the same dataset with justifications for each step is available in [Workflow Chapter 8](http://bioconductor.org/books/3.21/OSCA.workflows/segerstolpe-human-pancreas-smart-seq2.html#segerstolpe-human-pancreas-smart-seq2).


``` r
sce <- SegerstolpePancreasData()

# Quality control (using ERCCs).
qcstats <- perCellQCMetrics(sce)
filtered <- quickPerCellQC(qcstats, percent_subsets="altexps_ERCC_percent")
sce <- sce[, !filtered$discard]

# Normalization.
sce <- logNormCounts(sce)

# Feature selection, blocking on the individual of origin.
dec <- modelGeneVar(sce, block=sce$individual)
hvg <- getTopHVGs(dec, prop=0.1)

# Batch correction.
library(batchelor)
set.seed(1234)
sce <- correctExperiments(sce, batch=sce$individual, 
    subset.row=hvg, correct.all=TRUE)

# Clustering.
colLabels(sce) <- clusterCells(sce, use.dimred='corrected')

# Visualization.
sce <- runUMAP(sce, dimred = 'corrected')
gridExtra::grid.arrange(
    plotUMAP(sce, colour_by="label"),
    plotUMAP(sce, colour_by="individual"),
    ncol=2
)
```

<div class="figure">
<img src="analysis-overview_files/figure-html/quick-start2-umap-1.png" alt="UMAP plot of the pancreas dataset, where each point is a cell and is colored by the assigned cluster identity (left) or the individual of origin (right)." width="960" />
<p class="caption">(\#fig:quick-start2-umap)UMAP plot of the pancreas dataset, where each point is a cell and is colored by the assigned cluster identity (left) or the individual of origin (right).</p>
</div>

``` r
# Marker detection, blocking on the individual of origin.
markers <- findMarkers(sce, test.type="wilcox", direction="up", lfc=1)
```

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.5.1 (2025-06-13)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0  LAPACK version 3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] batchelor_1.24.0            bluster_1.18.0             
 [3] scran_1.36.0                scater_1.36.0              
 [5] ggplot2_3.5.2               scuttle_1.18.0             
 [7] scRNAseq_2.22.0             SingleCellExperiment_1.30.1
 [9] SummarizedExperiment_1.38.1 Biobase_2.68.0             
[11] GenomicRanges_1.60.0        GenomeInfoDb_1.44.0        
[13] IRanges_2.42.0              S4Vectors_0.46.0           
[15] BiocGenerics_0.54.0         generics_0.1.4             
[17] MatrixGenerics_1.20.0       matrixStats_1.5.0          
[19] BiocStyle_2.36.0            rebook_1.18.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_2.0.0           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          GenomicFeatures_1.60.0   
  [7] gypsum_1.4.0              farver_2.1.2             
  [9] rmarkdown_2.29            BiocIO_1.18.0            
 [11] vctrs_0.6.5               DelayedMatrixStats_1.30.0
 [13] memoise_2.0.1             Rsamtools_2.24.0         
 [15] RCurl_1.98-1.17           htmltools_0.5.8.1        
 [17] S4Arrays_1.8.1            AnnotationHub_3.16.0     
 [19] curl_6.4.0                BiocNeighbors_2.2.0      
 [21] Rhdf5lib_1.30.0           SparseArray_1.8.0        
 [23] rhdf5_2.52.1              sass_0.4.10              
 [25] alabaster.base_1.8.0      bslib_0.9.0              
 [27] alabaster.sce_1.8.0       httr2_1.1.2              
 [29] cachem_1.1.0              ResidualMatrix_1.18.0    
 [31] GenomicAlignments_1.44.0  igraph_2.1.4             
 [33] lifecycle_1.0.4           pkgconfig_2.0.3          
 [35] rsvd_1.0.5                Matrix_1.7-3             
 [37] R6_2.6.1                  fastmap_1.2.0            
 [39] GenomeInfoDbData_1.2.14   digest_0.6.37            
 [41] AnnotationDbi_1.70.0      dqrng_0.4.1              
 [43] irlba_2.3.5.1             ExperimentHub_2.16.0     
 [45] RSQLite_2.4.1             beachmat_2.24.0          
 [47] labeling_0.4.3            filelock_1.0.3           
 [49] httr_1.4.7                abind_1.4-8              
 [51] compiler_4.5.1            bit64_4.6.0-1            
 [53] withr_3.0.2               BiocParallel_1.42.1      
 [55] viridis_0.6.5             DBI_1.2.3                
 [57] HDF5Array_1.36.0          alabaster.ranges_1.8.0   
 [59] alabaster.schemas_1.8.0   rappdirs_0.3.3           
 [61] DelayedArray_0.34.1       rjson_0.2.23             
 [63] tools_4.5.1               vipor_0.4.7              
 [65] beeswarm_0.4.0            glue_1.8.0               
 [67] h5mread_1.0.1             restfulr_0.0.15          
 [69] rhdf5filters_1.20.0       grid_4.5.1               
 [71] cluster_2.1.8.1           gtable_0.3.6             
 [73] ensembldb_2.32.0          metapod_1.16.0           
 [75] BiocSingular_1.24.0       ScaledMatrix_1.16.0      
 [77] XVector_0.48.0            RcppAnnoy_0.0.22         
 [79] ggrepel_0.9.6             BiocVersion_3.21.1       
 [81] pillar_1.10.2             limma_3.64.1             
 [83] dplyr_1.1.4               BiocFileCache_2.16.0     
 [85] lattice_0.22-7            FNN_1.1.4.1              
 [87] rtracklayer_1.68.0        bit_4.6.0                
 [89] tidyselect_1.2.1          locfit_1.5-9.12          
 [91] Biostrings_2.76.0         knitr_1.50               
 [93] gridExtra_2.3             bookdown_0.43            
 [95] ProtGenerics_1.40.0       edgeR_4.6.2              
 [97] xfun_0.52                 statmod_1.5.0            
 [99] UCSC.utils_1.4.0          lazyeval_0.2.2           
[101] yaml_2.3.10               evaluate_1.0.4           
[103] codetools_0.2-20          tibble_3.3.0             
[105] alabaster.matrix_1.8.0    BiocManager_1.30.26      
[107] graph_1.86.0              cli_3.6.5                
[109] uwot_0.2.3                jquerylib_0.1.4          
[111] dichromat_2.0-0.1         Rcpp_1.0.14              
[113] dir.expiry_1.16.0         dbplyr_2.5.0             
[115] png_0.1-8                 XML_3.99-0.18            
[117] parallel_4.5.1            blob_1.2.4               
[119] AnnotationFilter_1.32.0   sparseMatrixStats_1.20.0 
[121] bitops_1.0-9              viridisLite_0.4.2        
[123] alabaster.se_1.8.0        scales_1.4.0             
[125] crayon_1.5.3              rlang_1.1.6              
[127] cowplot_1.1.3             KEGGREST_1.48.1          
```
</div>
